==> carpet-addons-not-found-1.18.2-2.0.0-sources.jar: carpetaddonsnotfound/instantmining/BlockBreakingSpeedRatioCalculator.java <==
package carpetaddonsnotfound.instantmining;

import carpetaddonsnotfound.helpers.WorldHelper;
import net.minecraft.class_1292;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1890;
import net.minecraft.class_2680;

//#if MC>12006
//$$ import net.minecraft.enchantment.Enchantment;
//$$ import net.minecraft.enchantment.Enchantments;
//$$ import net.minecraft.registry.DynamicRegistryManager;
//$$ import net.minecraft.registry.RegistryKeys;
//$$ import net.minecraft.registry.entry.RegistryEntry;
//#if MC>12101
//$$ import net.minecraft.registry.Registry;
//#endif
//#endif

public class BlockBreakingSpeedRatioCalculator {
  public static float getBlockBreakingSpeedRatio(class_1309 livingEntity, class_2680 blockState) {
    int efficiencyLevel = getEfficiencyLevel(livingEntity);
    int hasteAmplifier = class_1292.method_5575(livingEntity);
    class_1799 mainHand = livingEntity.method_6118(class_1304.field_6173);

    if (!class_1292.method_5576(livingEntity)
        || mainHand.method_7960()
        || efficiencyLevel < 5
        || hasteAmplifier < 1) {
      return 1.0f;
    }

    CompositeInstantMiningRatioCalculator instantMiningRatioCalculator = new CompositeInstantMiningRatioCalculator();
    return instantMiningRatioCalculator.getInstantMiningRatio(blockState, mainHand.method_7909());
  }

  private static int getEfficiencyLevel(class_1309 livingEntity) {
    //#if MC>12006
    //$$ DynamicRegistryManager registryManager = WorldHelper.getWorld(livingEntity).getRegistryManager();
    //#if MC>12101
    //$$ Registry<Enchantment> enchantmentsRegistry = registryManager.getOrThrow(RegistryKeys.ENCHANTMENT);
    //$$ RegistryEntry<Enchantment> efficiencyRegistryEntry = enchantmentsRegistry.getEntry(enchantmentsRegistry.get(Enchantments.EFFICIENCY));
    //$$ return EnchantmentHelper.getLevel(efficiencyRegistryEntry, livingEntity.getWeaponStack());
    //#else
    //$$ RegistryEntry<Enchantment> efficiencyRegistryEntry = registryManager.get(RegistryKeys.ENCHANTMENT).entryOf(Enchantments.EFFICIENCY);
    //$$ return EnchantmentHelper.getLevel(efficiencyRegistryEntry, livingEntity.getWeaponStack());
    //#endif
    //#else
    return class_1890.method_8234(livingEntity);
    //#endif
  }
}

==> carpet-addons-not-found-1.21.1-2.2.0-sources.jar: carpetaddonsnotfound/instantmining/BlockBreakingSpeedRatioCalculator.java <==
package carpetaddonsnotfound.instantmining;

import carpetaddonsnotfound.helpers.WorldHelper;
import net.minecraft.class_1292;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1887;
import net.minecraft.class_1890;
import net.minecraft.class_1893;
import net.minecraft.class_2680;
import net.minecraft.class_5455;
import net.minecraft.class_6880;
import net.minecraft.class_7924;

public class BlockBreakingSpeedRatioCalculator {
  public static float getBlockBreakingSpeedRatio(class_1309 livingEntity, class_2680 blockState) {
    int efficiencyLevel = getEfficiencyLevel(livingEntity);
    int hasteAmplifier = class_1292.method_5575(livingEntity);
    class_1799 mainHand = livingEntity.method_6118(class_1304.field_6173);

    if (!class_1292.method_5576(livingEntity)
        || mainHand.method_7960()
        || efficiencyLevel < 5
        || hasteAmplifier < 1) {
      return 1.0f;
    }

    CompositeInstantMiningRatioCalculator instantMiningRatioCalculator = new CompositeInstantMiningRatioCalculator();
    return instantMiningRatioCalculator.getInstantMiningRatio(blockState, mainHand.method_7909());
  }

  private static int getEfficiencyLevel(class_1309 livingEntity) {
    //#if MC>12006
    class_5455 registryManager = WorldHelper.getWorld(livingEntity).method_30349();
    //#if MC>12101
    //$$ Registry<Enchantment> enchantmentsRegistry = registryManager.getOrThrow(RegistryKeys.ENCHANTMENT);
    //$$ RegistryEntry<Enchantment> efficiencyRegistryEntry = enchantmentsRegistry.getEntry(enchantmentsRegistry.get(Enchantments.EFFICIENCY));
    //$$ return EnchantmentHelper.getLevel(efficiencyRegistryEntry, livingEntity.getWeaponStack());
    //#else
    class_6880<class_1887> efficiencyRegistryEntry = registryManager.method_30530(class_7924.field_41265).method_40290(class_1893.field_9131);
    return class_1890.method_8225(efficiencyRegistryEntry, livingEntity.method_59958());
    //#endif
    //#else
    //$$ return EnchantmentHelper.getEfficiency(livingEntity);
    //#endif
  }
}
